@@ -17,7 +17,7 @@ from osadl_matrix import OSADL_MATRIX
 def read_user_config():
     for path in [
         os.environ.get('FLICT_USERCONFIG'),
-        os.path.join(os.environ.get('HOME'), '.flict.cfg'),
+        os.path.join(os.environ.get('HOME', '/does/not/exist'), '.flict.cfg'),
     ]:
         try:
             with open(path) as i:
@@ -29,7 +29,7 @@ def read_user_config():
 
 _userconfig = read_user_config()
 
-flict_version = "1.0.10"
+flict_version = "1.0.12"
 
 SCRIPT_DIR = os.path.realpath(os.path.join(os.path.dirname(os.path.realpath(__file__)), "../"))
 
